@@ -1,7 +1,7 @@
 package App::Wubot::Check;
 use Moose;
 
-our $VERSION = '0.3.10'; # VERSION
+our $VERSION = '0.4.0'; # VERSION
 
 use Benchmark;
 use Class::Load;
@@ -19,7 +19,7 @@ App::Wubot::Check - perform checks for an instance of a monitor
 
 =head1 VERSION
 
-version 0.3.10
+version 0.4.0
 
 =head1 SYNOPSIS
 
@@ -36,54 +36,54 @@ instance through the reactor.
 
 =cut
 
-has 'key'      => ( is => 'ro',
-                    isa => 'Str',
-                    required => 1,
-                );
+has 'key'               => ( is => 'ro',
+                             isa => 'Str',
+                             required => 1,
+                         );
 
-has 'class'      => ( is => 'ro',
-                      isa => 'Str',
-                      required => 1,
-                  );
+has 'class'             => ( is => 'ro',
+                             isa => 'Str',
+                             required => 1,
+                         );
 
-has 'instance'   => ( is      => 'ro',
-                      lazy    => 1,
-                      default => sub {
-                          my $self = shift;
-                          my $class = $self->class;
+has 'instance'          => ( is      => 'ro',
+                             lazy    => 1,
+                             default => sub {
+                                 my $self = shift;
+                                 my $class = $self->class;
 
-                          Class::Load::load_class( $class );
-                          if ( $@ ) {
-                              die "ERROR: loading class: $class => $@";
-                          }
-                          return $class->new( key        => $self->key,
-                                              class      => $self->class,
-                                              cache_file => $self->cache_file,
-                                              reactor    => $self->reactor,
-                                          );
-                      },
-                  );
+                                 Class::Load::load_class( $class );
+                                 if ( $@ ) {
+                                     die "ERROR: loading class: $class => $@";
+                                 }
+                                 return $class->new( key        => $self->key,
+                                                     class      => $self->class,
+                                                     cache_file => $self->cache_file,
+                                                     reactor    => $self->reactor,
+                                                 );
+                             },
+                         );
 
-has 'cache_file' => ( is => 'ro',
-                      isa => 'Str',
-                      required => 1,
-                  );
+has 'cache_file'        => ( is => 'ro',
+                             isa => 'Str',
+                             required => 1,
+                         );
 
-has 'logger'  => ( is => 'ro',
-                   isa => 'Log::Log4perl::Logger',
-                   lazy => 1,
-                   default => sub {
-                       return Log::Log4perl::get_logger( __PACKAGE__ );
-                   },
-               );
+has 'logger'            => ( is => 'ro',
+                             isa => 'Log::Log4perl::Logger',
+                             lazy => 1,
+                             default => sub {
+                                 return Log::Log4perl::get_logger( __PACKAGE__ );
+                             },
+                         );
 
-has 'reactor_queue' => ( is => 'ro',
-                         isa => 'App::Wubot::LocalMessageStore',
-                         lazy => 1,
-                         default => sub {
-                             return App::Wubot::LocalMessageStore->new();
-                         }
-                     );
+has 'reactor_queue'     => ( is => 'ro',
+                             isa => 'App::Wubot::LocalMessageStore',
+                             lazy => 1,
+                             default => sub {
+                                 return App::Wubot::LocalMessageStore->new();
+                             }
+                         );
 
 has 'reactor_queue_dir' => ( is => 'ro',
                              isa => 'Str',
@@ -92,28 +92,26 @@ has 'reactor_queue_dir' => ( is => 'ro',
                              },
                          );
 
-has 'reactor'   => ( is => 'ro',
-                     isa => 'CodeRef',
-                     lazy => 1,
-                     default => sub {
-                         my ( $self ) = @_;
+has 'reactor'           => ( is => 'ro',
+                             isa => 'CodeRef',
+                             lazy => 1,
+                             default => sub {
+                                 my ( $self ) = @_;
 
-                         return sub {
-                             my ( $message, $config ) = @_;
+                                 return sub {
+                                     my ( $message, $config ) = @_;
+                                     $self->_react_results( $message, $config );
+                                 };
+                             },
+                         );
 
-                             $self->_react_results( $message, $config );
-
-                         };
-                     },
-                 );
-
-has 'wubot_reactor' => ( is => 'ro',
-                         isa => 'App::Wubot::Reactor',
-                         lazy => 1,
-                         default => sub {
-                             App::Wubot::Reactor->new();
-                         },
-                     );
+has 'wubot_reactor'     => ( is => 'ro',
+                             isa => 'App::Wubot::Reactor',
+                             lazy => 1,
+                             default => sub {
+                                 App::Wubot::Reactor->new();
+                             },
+                         );
 
 
 =head1 SUBROUTINES/METHODS
@@ -222,7 +220,8 @@ sub check {
             $message->{subject} = "Timed out after $timeout seconds";
         }
         else {
-            $self->logger->error( "CRITICAL: $error" );
+            my $key = $self->key;
+            $self->logger->error( "CRITICAL: $key: $error" );
             $message->{subject} = "CRITICAL: $error";
         }
 
@@ -248,6 +247,8 @@ sub check {
     my $diff = timediff( $end, $start );
     $self->logger->debug( $self->key, ":", timestr( $diff, 'all' ) );
 
+    return unless $results;
+
     if ( $results->{react} ) {
         $self->logger->debug( " - running rules defined in react" );
         $self->reactor->( $results->{react}, $config );
@@ -272,11 +273,14 @@ sub _react_results {
         return;
     }
 
-    # set the monitor config in the message
-    my $skip = { react => 1 };
-    for my $key ( keys %{ $config } ) {
-        next if $skip->{ $key };
-        $react->{"config.$key"} = $config->{$key};
+    # set the monitor config in the message.  don't overwrite config
+    # in the XMPP plugin
+    unless ( $config->{plugin} &&  $config->{plugin} eq 'App::Wubot::Plugin::XMPP' ) {
+        my $skip = { react => 1 };
+        for my $key ( keys %{ $config } ) {
+            next if $skip->{ $key };
+            $react->{"config.$key"} = $config->{$key};
+        }
     }
 
     unless ( ref $react eq "HASH" ) {
