@@ -1,7 +1,7 @@
 package App::Wubot::Plugin::FileTail;
 use Moose;
 
-our $VERSION = '0.3.10'; # VERSION
+our $VERSION = '0.4.0'; # VERSION
 
 use App::Wubot::Logger;
 use App::Wubot::Util::Tail;
@@ -35,7 +35,17 @@ with 'App::Wubot::Plugin::Roles::Plugin';
 sub init {
     my ( $self, $inputs ) = @_;
 
-    $self->path( $inputs->{config}->{path} );
+    if ( $inputs->{config}->{path} ) {
+        $self->path( $inputs->{config}->{path} );
+    }
+    else {
+        $self->logger->logdie( "ERROR: no path found in config" );
+    }
+
+     if ( exists $inputs->{config}->{detect_rename} ) {
+         $self->tail->detect_rename( $inputs->{config}->{detect_rename} );
+     }
+
 
     my $ignore;
     if ( $inputs->{config}->{ignore} ) {
@@ -87,7 +97,7 @@ App::Wubot::Plugin::FileTail - monitor a log file for all new lines
 
 =head1 VERSION
 
-version 0.3.10
+version 0.4.0
 
 =head1 SYNOPSIS
 
@@ -96,10 +106,12 @@ version 0.3.10
   ---
   delay: 30
   path: /var/log/messages
+  detect_rename: 0
   ignore:
     - my.ignore.string
     - some\sregexp\d+
 
+
 =head1 DESCRIPTION
 
 Monitor a log file for new lines.
@@ -115,6 +127,11 @@ matches, then no message will be sent.  All patterns in the 'ignore'
 array will get joined together with '|' and evaluated as a single
 regular expression.
 
+If 'detect_rename' is set to a false value in your configuration, then
+any apparent rename of the file will be ignored.  This could be
+necessary in some cases for files being tailed on a network-mounted
+filesystem.  The default is to check for renames (detect_rename=1).
+
 
 =head1 SUBROUTINES/METHODS
 
