@@ -1,7 +1,7 @@
 package App::Wubot::Plugin::Roles::Plugin;
 use Moose::Role;
 
-our $VERSION = '0.3.10'; # VERSION
+our $VERSION = '0.4.0'; # VERSION
 
 use App::Wubot::Logger;
 
@@ -12,7 +12,7 @@ App::Wubot::Plugin::Roles::Plugin - a role that should be used by all wubot plug
 
 =head1 VERSION
 
-version 0.3.10
+version 0.4.0
 
 =head1 SYNOPSIS
 
@@ -46,5 +46,11 @@ has 'logger'  => ( is => 'ro',
                    },
                );
 
+has 'reactor'  => ( is => 'ro',
+                    isa => 'CodeRef',
+                    required => 1,
+                );
+
+
 
 1;
