@@ -1,20 +1,24 @@
 package App::Wubot::Reactor::Console;
 use Moose;
 
-our $VERSION = '0.3.10'; # VERSION
+our $VERSION = '0.4.0'; # VERSION
 
 use POSIX qw(strftime);
+use Sys::Hostname qw();
 use Term::ANSIColor;
 
 use App::Wubot::Logger;
 
-has 'logger'  => ( is       => 'ro',
-                   isa      => 'Log::Log4perl::Logger',
-                   lazy     => 1,
-                   default  => sub {
-                       return Log::Log4perl::get_logger( __PACKAGE__ );
-                   },
-               );
+has 'logger'   => ( is       => 'ro',
+                    isa      => 'Log::Log4perl::Logger',
+                    lazy     => 1,
+                    default  => sub {
+                        return Log::Log4perl::get_logger( __PACKAGE__ );
+                    },
+                );
+
+my $hostname = Sys::Hostname::hostname();
+$hostname =~ s|\..*$||;
 
 my $valid_colors = { blue    => 'blue',
                      cyan    => 'cyan',
@@ -64,10 +68,10 @@ sub react {
 
     $self->logger->debug( "Console: $color: $subject" );
 
-    $message->{console}->{color} = $color;
+    $message->{console}->{$hostname}->{color} = $color;
     print color $color;
 
-    $message->{console}->{text}  = $subject;
+    $message->{console}->{$hostname}->{text}  = $subject;
     print $subject;
 
     print color 'reset';
@@ -90,7 +94,7 @@ App::Wubot::Reactor::Console - display a notification to stdout
 
 =head1 VERSION
 
-version 0.3.10
+version 0.4.0
 
 =head1 SYNOPSIS
 
