@@ -1,7 +1,7 @@
 package App::Wubot::Util::Tail;
 use Moose;
 
-our $VERSION = '0.3.10'; # VERSION
+our $VERSION = '0.4.0'; # VERSION
 
 use Fcntl qw( SEEK_END SEEK_CUR SEEK_SET O_NONBLOCK O_RDONLY );
 
@@ -14,7 +14,7 @@ App::Wubot::Util::Tail - follow the tail of a growing file
 
 =head1 VERSION
 
-version 0.3.10
+version 0.4.0
 
 =head1 SYNOPSIS
 
@@ -90,6 +90,12 @@ has 'position'  => ( is      => 'rw',
                      default => undef,
                  );
 
+has 'detect_rename' => ( is      => 'rw',
+                         isa     => 'Bool',
+                         default => 1,
+                     );
+
+
 =head1 SUBROUTINES/METHODS
 
 =over 8
@@ -104,6 +110,13 @@ a new one was re-opened.  In either case, the reset_callback is
 executed and is passed the appropriate text:
 
   filehandle was truncated: {$path}
+
+If the 'detect_rename' attribute is true (the default), then the
+filehandle will also be checked to see if it was renamed.  This will
+detect if the date on the file has increased even though the
+filehandle has nothing available to read.  In the event of a rename,
+the reset_callback will be executed.
+
   file was renamed: {$path}
 
 =cut
@@ -115,6 +128,10 @@ sub get_lines {
 
     my $path = $self->path;
 
+    unless ( $path ) {
+        $self->logger->logconfess( "FATAL: FileTail: no path set" );
+    }
+
     unless ( -r $path ) {
         $self->reset_callback->( "path not readable: $path" );
         return;
@@ -135,7 +152,7 @@ sub get_lines {
     my $was_truncated = $end_pos < $self->position ? 1 : 0;
     my $was_renamed   = $self->lastread && $mtime > $self->lastread ? 1 : 0;
 
-    if ( $was_truncated || $was_renamed ) {
+    if ( $was_truncated || ( $was_renamed && $self->detect_rename ) ) {
 
         if ( $was_truncated ) {
             $self->reset_callback->( "file was truncated: $path" );
